@@ -20,6 +20,10 @@ from ..usecases.face_emotion import FaceEmotionConfig, FaceEmotionUseCase
 from ..usecases.parking_space_detection import ParkingSpaceConfig, ParkingSpaceUseCase
 from ..usecases.underwater_pollution_detection import UnderwaterPlasticConfig, UnderwaterPlasticUseCase
 from ..usecases.pedestrian_detection import PedestrianDetectionConfig, PedestrianDetectionUseCase
+from ..usecases.car_damage_detection import CarDamageConfig, CarDamageDetectionUseCase
+from ..usecases.age_detection import AgeDetectionUseCase, AgeDetectionConfig
+from ..usecases.weld_defect_detection import WeldDefectUseCase,WeldDefectConfig
+from ..usecases.price_tag_detection import PriceTagUseCase, PriceTagConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -34,9 +38,13 @@ __all__ = [
     'PotholeSegmentationUseCase',
     'ParkingSpaceUseCase',
     'FlareAnalysisUseCase',
+    'CarDamageDetectionUseCase',
     'FaceEmotionUseCase',
     'UnderwaterPlasticUseCase',
     'PedestrianDetectionUseCase',
+    'AgeDetectionUseCase',
+    'WeldDefectUseCase',
+    'PriceTagUseCase',
     'PeopleCountingConfig',
     'PotholeConfig',
     'CustomerServiceConfig',
@@ -47,8 +55,12 @@ __all__ = [
     'VehicleMonitoringConfig',
     'ParkingSpaceConfig',
     'FireSmokeConfig',
+    'CarDamageConfig',
     'FlareAnalysisConfig',
     'FaceEmotionConfig',
-    'UnderwaterPlasticUseCase',
+    'UnderwaterPlasticConfig',
     'PedestrianDetectionConfig',
+    'AgeDetectionConfig',
+    'WeldDefectConfig',
+    'PriceTagConfig'
 ]
