@@ -1,7 +1,7 @@
 """
-Face Emotion Use Case for Post-Processing
+Face Emotion Detection Use Case for Post-Processing
 
-This module provides Face Emotion functionality with congestion detection,
+This module provides Face Emotion Detection functionality with congestion detection,
 zone analysis, and alert generation.
 
 """
@@ -29,7 +29,7 @@ from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class FaceEmotionConfig(BaseConfig):
-    """Configuration for emotion detection use case in Face Emotion."""
+    """Configuration for emotion detection use case in Face Emotion Detection."""
     # Smoothing configuration
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"  # "window" or "observability"
@@ -49,14 +49,13 @@ class FaceEmotionConfig(BaseConfig):
         default_factory=lambda: ['angry', 'happy', 'sad', 'surprised']
     )
 
-
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
             0: "angry",
             1: "happy",
             2: "sad",
-            3: "surprised"
+            3: "surprised",
         }
     )
 
@@ -102,8 +101,8 @@ class FaceEmotionUseCase(BaseProcessor):
         return inter_area / union
 
     @staticmethod
-    def _deduplicate_emotion(detections, iou_thresh=0.99):
-        """Suppress duplicate/overlapping emotion with same label and high IoU."""
+    def _deduplicate_emotions(detections, iou_thresh=0.7):
+        """Suppress duplicate/overlapping emotions with same label and high IoU."""
         filtered = []
         used = [False] * len(detections)
         for i, det in enumerate(detections):
@@ -175,7 +174,11 @@ class FaceEmotionUseCase(BaseProcessor):
             return "00:00:00.00"
         
         is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
-
+        
+        # if is_video_chunk:
+        #     # For video chunks, use video_timestamp from stream_info
+        #     video_timestamp = stream_info.get("video_timestamp", 0.0)
+        #     return self._format_timestamp_for_video(video_timestamp)
         if stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
             # If video format, return video timestamp
             stream_time_str = stream_info.get("video_timestamp", "")
@@ -204,10 +207,10 @@ class FaceEmotionUseCase(BaseProcessor):
         
         is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
         
-        # if is_video_chunk:
-        #     # For video chunks, start from 00:00:00
-        #     return "00:00:00"
-        if stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
+        if is_video_chunk:
+            # For video chunks, start from 00:00:00
+            return "00:00:00"
+        elif stream_info.get("input_settings", {}).get("stream_type","video_file")=="video_file":
             # If video format, start from 00:00:00
             return "00:00:00"
         else:
@@ -232,7 +235,7 @@ class FaceEmotionUseCase(BaseProcessor):
             dt = dt.replace(minute=0, second=0, microsecond=0)
             return dt.strftime('%Y:%m:%d %H:%M:%S')
 
-    """Face Emotion use case with emotion smoothing and alerting."""
+    """Face Emotion Detection use case with emotion smoothing and alerting."""
 
     def __init__(self):
         super().__init__("face_emotion")
@@ -269,7 +272,7 @@ class FaceEmotionUseCase(BaseProcessor):
 
     def process(self, data: Any, config: ConfigProtocol, context: Optional[ProcessingContext] = None, stream_info: Optional[Dict[str, Any]] = None) -> ProcessingResult:
         """
-        Main entry point for Face Emotion post-processing.
+        Main entry point for Face Emotion Detection post-processing.
         Applies category mapping, emotion smoothing, counting, alerting, and summary generation.
         Returns a ProcessingResult with all relevant outputs.
         """
@@ -326,7 +329,7 @@ class FaceEmotionUseCase(BaseProcessor):
             if self.tracker is None:
                 tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
-                self.logger.info("Initialized AdvancedTracker for Face Emotion and tracking")
+                self.logger.info("Initialized AdvancedTracker for Face Emotion Detection and tracking")
             
             # The tracker expects the data in the same format as input
             # It will add track_id and frame_id to each detection
@@ -337,7 +340,7 @@ class FaceEmotionUseCase(BaseProcessor):
             self.logger.warning(f"AdvancedTracker failed: {e}")
 
         # Deduplicate overlapping emotions (same label, high IoU)
-        processed_data = self._deduplicate_emotion(processed_data, iou_thresh=0.95)
+        processed_data = self._deduplicate_emotions(processed_data, iou_thresh=0.95)
 
         # Update emotion tracking state for total count per label
         self._update_emotion_tracking_state(processed_data)
@@ -419,7 +422,7 @@ class FaceEmotionUseCase(BaseProcessor):
         # Also clear canonical tracking structures
         self._track_aliases.clear()
         self._canonical_tracks.clear()
-        self.logger.info("Face Emotion tracking state reset")
+        self.logger.info("Face Emotion Detection tracking state reset")
     
     def reset_all_tracking(self) -> None:
         """
@@ -470,7 +473,7 @@ class FaceEmotionUseCase(BaseProcessor):
             human_text = "\n".join(human_text_lines)
 
             event = {
-                "type": "face_emotion",
+                "type": "face_emotion_detection",
                 "stream_time": datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S UTC"),
                 "level": level,
                 "intensity": round(intensity, 1),
@@ -479,7 +482,7 @@ class FaceEmotionUseCase(BaseProcessor):
                     "max_value": 10,
                     "level_settings": {"info": 2, "warning": 5, "critical": 7}
                 },
-                "application_name": "Face Emotion Detection",
+                "application_name": "Face Emotion Detection System",
                 "application_version": "1.2",
                 "location_info": None,
                 "human_text": human_text
@@ -489,25 +492,25 @@ class FaceEmotionUseCase(BaseProcessor):
         # Add alert events
         for alert in alerts:
             total_emotions = counting_summary.get("total_count", 0)
-            intensity_message = "ALERT: Low congestion in the scene"
+            intensity_message = "ALERT: Low emotion in the scene"
             if config.alert_config and config.alert_config.count_thresholds:
                 threshold = config.alert_config.count_thresholds.get("all", 15)
                 percentage = (total_emotions / threshold) * 100 if threshold > 0 else 0
                 if percentage < 20:
-                    intensity_message = "ALERT: Low congestion in the scene"
+                    intensity_message = "ALERT: Low emotion in the scene"
                 elif percentage <= 50:
-                    intensity_message = "ALERT: Moderate congestion in the scene"
+                    intensity_message = "ALERT: Moderate emotion in the scene"
                 elif percentage <= 70:
-                    intensity_message = "ALERT: Heavy congestion in the scene"
+                    intensity_message = "ALERT: Heavy emotion in the scene"
                 else:
-                    intensity_message = "ALERT: Severe congestion in the scene"
+                    intensity_message = "ALERT: Severe emotion in the scene"
             else:
                 if total_emotions > 15:
-                    intensity_message = "ALERT: Heavy congestion in the scene"
+                    intensity_message = "ALERT: Heavy emotion in the scene"
                 elif total_emotions == 1:
-                    intensity_message = "ALERT: Low congestion in the scene"
+                    intensity_message = "ALERT: Low emotion in the scene"
                 else:
-                    intensity_message = "ALERT: Moderate congestion in the scene"
+                    intensity_message = "ALERT: Moderate emotion in the scene"
 
             alert_event = {
                 "type": alert.get("type", "congestion_alert"),
@@ -556,16 +559,11 @@ class FaceEmotionUseCase(BaseProcessor):
         start_timestamp = self._get_start_timestamp_str(stream_info)
 
         human_text_lines = []
-        if total_emotions == 0 and counting_summary.get("per_category_count"):
-            total_emotions = sum(counting_summary["per_category_count"].values())
-            counting_summary["total_count"] = total_emotions
-            print(f"DEBUGGG___total_emotions: {counting_summary}")
 
         # CURRENT FRAME section
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
-        # human_text_lines.append("")
         if total_emotions > 0:
-            category_counts = [f"{count} {cat}" for cat, count in per_category_count.items()]
+            category_counts = [f"\t{count} {cat}" for cat, count in per_category_count.items()]
             if len(category_counts) == 1:
                 emotions_text = f"\t{category_counts[0]} detected"
             elif len(category_counts) == 2:
@@ -590,8 +588,8 @@ class FaceEmotionUseCase(BaseProcessor):
         human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
-            "type": "emotion_tracking",
-            "category": "emotion",
+            "type": "face_emotion_detection",
+            "category": "general",
             "count": total_emotions,
             "insights": insights,
             "summary": summary,
@@ -663,13 +661,13 @@ class FaceEmotionUseCase(BaseProcessor):
             percentage = (total_emotions / intensity_threshold) * 100
             
             if percentage < 20:
-                insights.append(f"INTENSITY: Low congestion in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY: Low emotion in the scene ({percentage:.1f}% of capacity)")
             elif percentage <= 50:
-                insights.append(f"INTENSITY: Moderate congestion in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY: Moderate emotion in the scene ({percentage:.1f}% of capacity)")
             elif percentage <= 70:
-                insights.append(f"INTENSITY:  Heavy congestion in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY:  Heavy emotion in the scene ({percentage:.1f}% of capacity)")
             else:
-                insights.append(f"INTENSITY: Severe congestion in the scene ({percentage:.1f}% of capacity)")
+                insights.append(f"INTENSITY: Severe emotion in the scene ({percentage:.1f}% of capacity)")
         # else:
         #     # Fallback to hardcoded thresholds if no alert config is set
         #     if total_emotions > 15:
