@@ -99,7 +99,6 @@ class WeldDefectUseCase(BaseProcessor):
                 continue
             group = [i]
             for j in range(i+1, len(detections)):
-
                 if used[j]:
                     continue
                 if det.get("category") == detections[j].get("category"):
@@ -349,19 +348,15 @@ class WeldDefectUseCase(BaseProcessor):
         total_defect_counts = counting_summary.get("total_defect_counts", {})
         cumulative_total = sum(total_defect_counts.values()) if total_defect_counts else 0
         per_category_count = counting_summary.get("per_category_count", {})
-        target_categories = config.target_defect_categories
 
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
         current_timestamp = self._get_current_timestamp_str(stream)
         start_timestamp = self._get_start_timestamp_str(stream)
 
         human_text_lines = []
-        target_counts = {cat: per_category_count.get(cat, 0) for cat in target_categories}
-        total_target_defects = sum(target_counts.values())
-
-        if total_target_defects > 0:
-            human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
-            category_counts = [f"{count} {cat}" for cat, count in target_counts.items() if count > 0]
+        human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
+        if total_defects > 0:
+            category_counts = [f"{count} {cat}" for cat, count in per_category_count.items()]
             if len(category_counts) == 1:
                 defects_text = category_counts[0] + " detected"
             elif len(category_counts) == 2:
@@ -369,20 +364,21 @@ class WeldDefectUseCase(BaseProcessor):
             else:
                 defects_text = f"{', '.join(category_counts[:-1])}, and {category_counts[-1]} detected"
             human_text_lines.append(f"\t- {defects_text}")
+        else:
+            human_text_lines.append(f"\t- No defects detected")
 
-        if total_target_defects > 0:
-            human_text_lines.append("")
-            human_text_lines.append(f"ALERTS SINCE @ {start_timestamp}:")
-            human_text_lines.append(f"\t- Total Defects Detected: {sum(count for cat, count in total_defect_counts.items() if cat in target_categories)}")
-            for cat, count in total_defect_counts.items():
-                if count > 0 and cat in target_categories:
-                    human_text_lines.append(f"\t- {cat}: {count}")
+        human_text_lines.append("")
+        human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
+        human_text_lines.append(f"\t- Total Defects Detected: {cumulative_total}")
+        for cat, count in total_defect_counts.items():
+            if count > 0:
+                human_text_lines.append(f"\t- {cat}: {count}")
 
-        human_text = "\n".join(human_text_lines) if human_text_lines else "No critical defects detected"
+        human_text = "\n".join(human_text_lines)
 
         tracking_stat = {
             "type": "weld_defect_tracking",
-            "category": "defect",
+            "category": "weld",
             "count": total_defects,
             "insights": insights,
             "summary": summary,
